message property
Log payload. String transports call toString; structured transports (e.g. HttpTransport) can inspect the runtime type to embed rich data.
Implementation
final Object message;
Log payload. String transports call toString; structured transports (e.g. HttpTransport) can inspect the runtime type to embed rich data.
final Object message;