config property

Map<String, dynamic> config
final

Arbitrary key/value options passed to the transport at construction time.

Keys and their meanings are specific to each Transport subclass and documented on the concrete class.

Implementation

final Map<String, dynamic> config;