LogLevel enum

Severity levels for log events, ordered from lowest to highest.

Use trace for fine-grained diagnostic output and fatal for unrecoverable failures. Each Transport filters events by comparing event.level.index >= transport.level.index.

Inheritance
Available extensions

Values

trace → const LogLevel

Finest-grained diagnostic messages, typically only useful during development (e.g. function entry/exit points).

debug → const LogLevel

Detailed information useful during debugging but suppressed in normal production runs.

info → const LogLevel

Informational messages confirming that things are working as expected.

warn → const LogLevel

Potentially harmful situations that deserve attention but do not prevent normal operation.

error → const LogLevel

Error events that might still allow the application to continue running.

fatal → const LogLevel

Very severe error events that usually lead the application to terminate.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.